#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library
from persistent import Persistent

# import interfaces
from pyams_content.features.alert.interfaces import IAlertItem
from pyams_content.interfaces import MANAGE_SITE_ROOT_PERMISSION
from pyams_form.interfaces.form import IFormContextPermissionChecker

# import packages
from pyams_content.component.links import InternalReferenceMixin
from pyams_utils.adapter import adapter_config, ContextAdapter
from zope.container.contained import Contained
from zope.interface import implementer
from zope.schema.fieldproperty import FieldProperty


@implementer(IAlertItem)
class AlertItem(Persistent, Contained, InternalReferenceMixin):
    """Alert item persistent class"""

    visible = FieldProperty(IAlertItem['visible'])
    gravity = FieldProperty(IAlertItem['gravity'])
    message = FieldProperty(IAlertItem['message'])
    reference = FieldProperty(IAlertItem['reference'])
    start_date = FieldProperty(IAlertItem['start_date'])
    end_date = FieldProperty(IAlertItem['end_date'])
    maximum_interval = FieldProperty(IAlertItem['maximum_interval'])


@adapter_config(context=IAlertItem, provides=IFormContextPermissionChecker)
class AlertitemPermissionChecker(ContextAdapter):
    """Alert item permission checker"""

    edit_permission = MANAGE_SITE_ROOT_PERMISSION
