#
# Copyright (c) 2008-2016 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.shared.common.interfaces import ISharedSite, IBaseSharedTool, ISharedContent, \
    IDeletableElement, IWfSharedContentPortalContext
from pyams_sequence.interfaces import ISequentialIdTarget
from pyams_workflow.interfaces import IWorkflowPublicationSupport
from zope.container.interfaces import IContainer

# import packages
from zope.container.constraints import containers, contains
from zope.interface import Attribute, Interface

from pyams_content import _


BLOG_CONTENT_TYPE = 'blog'
BLOG_CONTENT_NAME = _("Blog post")


class IWfBlogPost(IWfSharedContentPortalContext):
    """Blog topic interface"""


class IWfBlogPostFactory(Interface):
    """Blog post factory interface"""


class IBlogPost(ISharedContent, IDeletableElement):
    """Workflow managed blog post interface"""

    containers('.IBlogFolder')


class IBlogFolder(IContainer, IDeletableElement):
    """Blog folder interface"""

    containers('.IBlogManager', '.IBlogFolder')
    contains('.IBlogFolder', '.IBlogPost')


class IBlogFolderFactory(Interface):
    """Blog folder factory interface"""


class IBlogManager(ISharedSite, IBaseSharedTool, IWorkflowPublicationSupport, IDeletableElement, ISequentialIdTarget):
    """Blog manager interface"""

    contains(IBlogFolder)

    folder_factory = Attribute("Blog folder factory")

    topic_content_type = Attribute("Topic content type")
    topic_content_factory = Attribute("Topic content factory")


class IBlogManagerFactory(Interface):
    """Blog manager factory interface"""
